import {
    IsArray,

    IsBase64,

    IsBoolean,

    IsObject,
    IsOptional,
    IsString
} from "class-validator";
import { Address } from '../entities/Address';
import { RunnerOrganisation } from '../entities/RunnerOrganisation';
import { RunnerTeam } from '../entities/RunnerTeam';
import { ResponseRunnerGroup } from './ResponseRunnerGroup';

/**
 * Defines the runnerOrganisation response.
*/
export class ResponseRunnerOrganisation extends ResponseRunnerGroup {

    /**
     * The runnerOrganisation's address.
     */
    @IsObject()
    @IsOptional()
    address?: Address;

    /**
     * The runnerOrganisation associated teams.
     */
    @IsArray()
    teams: RunnerTeam[];

    /**
     * The organisation's registration key.
     * If registration is disabled this is null.
     */
    @IsString()
    @IsOptional()
    @IsBase64()
    registrationKey?: string;

    /**
     * Is registration enabled for the organisation?
     */
    @IsOptional()
    @IsBoolean()
    registrationEnabled?: boolean = true;

    /**
     * Creates a ResponseRunnerOrganisation object from a runnerOrganisation.
     * @param org The runnerOrganisation the response shall be build for.
     */
    public constructor(org: RunnerOrganisation) {
        super(org);
        this.address = org.address;
        this.teams = org.teams;
        if (!org.key) { this.registrationEnabled = false; }
        else { this.registrationKey = Buffer.from(org.key).toString('base64'); }
    }
}
